Bootswatch: Free themes for Bootstrap

# Free themes for Bootstrap

#### Easy to Install

Simply download a CSS file and replace the one in Bootstrap. No messing around with hex values.

#### Customizable

Changes are contained in just two SASS files, enabling further customization and ensuring forward compatibility.

#### Tuned for 4.4.1

Themes are built for the latest version of Bootstrap. 2.3.2, 3.4.1, and other releases are also available to download.

#### Open Source

Bootstrap themes are released under the MIT License and maintained by the community on GitHub.

#### Get Plugged In

An API is available for integrating with your platform. In use by NodeBB and many more.

#### Stay Updated

Be notified about updates by subscribing via RSS feed, email, Twitter, or Tumblr.

### Cerulean

A calm blue sky

Preview
Download

### Cosmo

An ode to Metro

Preview
Download

### Cyborg

Jet black and electric blue

Preview
Download

### Darkly

Flatly in night mode

Preview
Download

### Flatly

Flat and modern

Preview
Download

### Journal

Crisp like a new sheet of paper

Preview
Download

### Litera

The medium is the message

Preview
Download

### Lumen

Light and shadow

Preview
Download

### Lux

A touch of class

Preview
Download

### Materia

Material is the metaphor

Preview
Download

### Minty

A fresh feel

Preview
Download

### Pulse

A trace of purple

Preview
Download

### Sandstone

A touch of warmth

Preview
Download

### Simplex

Mini and minimalist

Preview
Download

### Sketchy

A hand-drawn look for mockups and mirth

Preview
Download

### Slate

Shades of gunmetal gray

Preview
Download

### Solar

A spin on Solarized

Preview
Download

### Spacelab

Silvery and sleek

Preview
Download

### Superhero

The brave and the blue

Preview
Download

### United

Ubuntu orange and unique font

Preview
Download

### Yeti

A friendly foundation

Preview
Download

# Want more?

Check out these premium templates from 3rd Wave Media.

### CoderPro

Startup template for software projects

View Details

### Nova Pro

The best way to promote your mobile app

View Details

### Dev Card

A portfolio template for developers

View Details

### Ashton

A single page portfolio template

View Details

### Repute

A responsive multipurpose theme

View Details

### Datta Able

An admin template and UI kit

View Details

# Building with React?

Check out these React Bootstrap templates from Divjoy.

### Joy

Multi-page startup template

View Details

### Light

Sass template with auth flow

View Details

### Create Your Own

With the Divjoy template editor

View Details

# Still looking?

Learn to code your own themes with these books from Amazon. As an associate, we earn a cut of each sale.

### HTML & CSS

Jon Duckett

Buy Now

### Eloquent JavaScript

Marijn Haverbeke

Buy Now

### CSS Secrets

Lea Verou

Buy Now

# Good luck have fun!

Or learn to code by playing games with Codepip.

### Flexbox Froggy

A game for learning CSS Flexbox

Play Now

### Grid Garden

A game for learning CSS Grid

Play Now

### Code Crunchers

A game for learning JavaScript Math

Play Now